/* -*- c++ -*- */
/*
 * Copyright 2006,2009,2013 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 */

#if HAVE_CONFIG_H
#include <config.h>
#endif

#include <gnuradio/constants.h>
#include <boost/dll/runtime_symbol_info.hpp>
#include <boost/filesystem/path.hpp>
#include <cstdlib>

using boost::filesystem::path;

namespace gr {

const std::string prefix()
{
    // Use "GR_PREFIX" environment variable when specified
    const char* prefix = std::getenv("GR_PREFIX");
    if (prefix != NULL)
        return prefix;

    path prefix_rel_lib = "../";
    path gr_runtime_lib_path = boost::dll::this_line_location();
    // Ensure that the lib path is absolute (see next comment)
    if (gr_runtime_lib_path.is_relative())
        gr_runtime_lib_path = boost::filesystem::absolute(gr_runtime_lib_path);
    // Canonize before decomposing path so result is reliable and without symlinks
    // Since we know lib path is absolute, pass "/" to avoid implicit current_path()
    // which fails when working dir is deleted (this happens in CI testing)
    path canonical_lib_path = boost::filesystem::canonical(gr_runtime_lib_path, "/");
    path prefix_path = canonical_lib_path.parent_path() / prefix_rel_lib;
    return prefix_path.lexically_normal().string();
}

const std::string sysconfdir()
{
    path sysconfdir_rel_prefix = "../etc";
    path prefix_path = prefix();
    path sysconfdir_path = prefix_path / sysconfdir_rel_prefix;

    return sysconfdir_path.lexically_normal().string();
}

const std::string prefsdir()
{
    path prefsdir_rel_prefix = "../etc/gnuradio/conf.d";
    path prefix_path = prefix();
    path prefsdir_path = prefix_path / prefsdir_rel_prefix;

    return prefsdir_path.lexically_normal().string();
}

const std::string build_date() { return "Tue, 28 Mar 2023 02:45:43Z"; }

const std::string version() { return "3.9.8.0-rc1"; }

// Return individual parts of the version
const std::string major_version() { return "3"; }

const std::string api_version() { return "9"; }

const std::string minor_version() { return "8"; }

const std::string c_compiler() { return "x86_64-nilrt-linux-gcc (GCC) 10.3.0 \nCopyright (C) 2020 Free Software Foundation, Inc. \nThis is free software see the source for copying conditions.  There is NO \nwarranty not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."; }

const std::string cxx_compiler() { return "x86_64-nilrt-linux-g++ (GCC) 10.3.0 \nCopyright (C) 2020 Free Software Foundation, Inc. \nThis is free software see the source for copying conditions.  There is NO \nwarranty not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."; }

const std::string compiler_flags() { return "/home/rfmibuild/myagent/_work/_r/0/src/rtos/rtosfeedsd/rtos_oe_feeds/objects/oe_feed_extras/linuxU/x64/gcc-4.7-oe/release/build-extra/tmp-glibc/work/core2-64-nilrt-linux/gnuradio/3.9.8.0-rc1-r0/recipe-sysroot-native/usr/bin/x86_64-nilrt-linux/x86_64-nilrt-linux-gcc:::-DNDEBUG  -m64 -march=core2 -mtune=core2 -msse3 -mfpmath=sse  --sysroot=/home/rfmibuild/myagent/_work/_r/0/src/rtos/rtosfeedsd/rtos_oe_feeds/objects/oe_feed_extras/linuxU/x64/gcc-4.7-oe/release/build-extra/tmp-glibc/work/core2-64-nilrt-linux/gnuradio/3.9.8.0-rc1-r0/recipe-sysroot  -O2 -pipe -g -feliminate-unused-debug-types -fmacro-prefix-map=/home/rfmibuild/myagent/_work/_r/0/src/rtos/rtosfeedsd/rtos_oe_feeds/objects/oe_feed_extras/linuxU/x64/gcc-4.7-oe/release/build-extra/tmp-glibc/work/core2-64-nilrt-linux/gnuradio/3.9.8.0-rc1-r0=/usr/src/debug/gnuradio/3.9.8.0-rc1-r0                      -fdebug-prefix-map=/home/rfmibuild/myagent/_work/_r/0/src/rtos/rtosfeedsd/rtos_oe_feeds/objects/oe_feed_extras/linuxU/x64/gcc-4.7-oe/release/build-extra/tmp-glibc/work/core2-64-nilrt-linux/gnuradio/3.9.8.0-rc1-r0=/usr/src/debug/gnuradio/3.9.8.0-rc1-r0                      -fdebug-prefix-map=/home/rfmibuild/myagent/_work/_r/0/src/rtos/rtosfeedsd/rtos_oe_feeds/objects/oe_feed_extras/linuxU/x64/gcc-4.7-oe/release/build-extra/tmp-glibc/work/core2-64-nilrt-linux/gnuradio/3.9.8.0-rc1-r0/recipe-sysroot=                      -fdebug-prefix-map=/home/rfmibuild/myagent/_work/_r/0/src/rtos/rtosfeedsd/rtos_oe_feeds/objects/oe_feed_extras/linuxU/x64/gcc-4.7-oe/release/build-extra/tmp-glibc/work/core2-64-nilrt-linux/gnuradio/3.9.8.0-rc1-r0/recipe-sysroot-native=   -m64 -march=core2 -mtune=core2 -msse3 -mfpmath=sse  --sysroot=/home/rfmibuild/myagent/_work/_r/0/src/rtos/rtosfeedsd/rtos_oe_feeds/objects/oe_feed_extras/linuxU/x64/gcc-4.7-oe/release/build-extra/tmp-glibc/work/core2-64-nilrt-linux/gnuradio/3.9.8.0-rc1-r0/recipe-sysroot -fvisibility=hidden -Wsign-compare -Wall -Wno-uninitialized \n/home/rfmibuild/myagent/_work/_r/0/src/rtos/rtosfeedsd/rtos_oe_feeds/objects/oe_feed_extras/linuxU/x64/gcc-4.7-oe/release/build-extra/tmp-glibc/work/core2-64-nilrt-linux/gnuradio/3.9.8.0-rc1-r0/recipe-sysroot-native/usr/bin/x86_64-nilrt-linux/x86_64-nilrt-linux-g++:::-DNDEBUG  -m64 -march=core2 -mtune=core2 -msse3 -mfpmath=sse  --sysroot=/home/rfmibuild/myagent/_work/_r/0/src/rtos/rtosfeedsd/rtos_oe_feeds/objects/oe_feed_extras/linuxU/x64/gcc-4.7-oe/release/build-extra/tmp-glibc/work/core2-64-nilrt-linux/gnuradio/3.9.8.0-rc1-r0/recipe-sysroot  -O2 -pipe -g -feliminate-unused-debug-types -fmacro-prefix-map=/home/rfmibuild/myagent/_work/_r/0/src/rtos/rtosfeedsd/rtos_oe_feeds/objects/oe_feed_extras/linuxU/x64/gcc-4.7-oe/release/build-extra/tmp-glibc/work/core2-64-nilrt-linux/gnuradio/3.9.8.0-rc1-r0=/usr/src/debug/gnuradio/3.9.8.0-rc1-r0                      -fdebug-prefix-map=/home/rfmibuild/myagent/_work/_r/0/src/rtos/rtosfeedsd/rtos_oe_feeds/objects/oe_feed_extras/linuxU/x64/gcc-4.7-oe/release/build-extra/tmp-glibc/work/core2-64-nilrt-linux/gnuradio/3.9.8.0-rc1-r0=/usr/src/debug/gnuradio/3.9.8.0-rc1-r0                      -fdebug-prefix-map=/home/rfmibuild/myagent/_work/_r/0/src/rtos/rtosfeedsd/rtos_oe_feeds/objects/oe_feed_extras/linuxU/x64/gcc-4.7-oe/release/build-extra/tmp-glibc/work/core2-64-nilrt-linux/gnuradio/3.9.8.0-rc1-r0/recipe-sysroot=                      -fdebug-prefix-map=/home/rfmibuild/myagent/_work/_r/0/src/rtos/rtosfeedsd/rtos_oe_feeds/objects/oe_feed_extras/linuxU/x64/gcc-4.7-oe/release/build-extra/tmp-glibc/work/core2-64-nilrt-linux/gnuradio/3.9.8.0-rc1-r0/recipe-sysroot-native=  -fvisibility-inlines-hidden  -m64 -march=core2 -mtune=core2 -msse3 -mfpmath=sse  --sysroot=/home/rfmibuild/myagent/_work/_r/0/src/rtos/rtosfeedsd/rtos_oe_feeds/objects/oe_feed_extras/linuxU/x64/gcc-4.7-oe/release/build-extra/tmp-glibc/work/core2-64-nilrt-linux/gnuradio/3.9.8.0-rc1-r0/recipe-sysroot -fvisibility=hidden -Wsign-compare -Wall -Wno-uninitialized"; }

const std::string build_time_enabled_components() { return "testing-support;python-support;post-install;man-pages;gnuradio-runtime;gnuradio-companion;gr-blocks;gr-fec;gr-fft;gr-filter;gr-analog;gr-digital;gr-audio;* alsa;* oss;gr-channels;gr-qtgui;gr-trellis;gr-utils;gr_modtool;gr_blocktool;gr-wavelet;gr-zeromq;gr-network"; }

const std::string pybind_version() { return "2.6.2"; }

} /* namespace gr */
